from .base import BaseClient as __BaseClient, convert_bool
from typing import List as _List


class Error:
    """
    Error response returned when the request is unsuccessful.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "code" in data:
            self.code: str = str(data["code"])
        else:
            self.code: str = None
        if "message" in data:
            self.message: str = str(data["message"])
        else:
            self.message: str = None
        if "details" in data:
            self.details: str = str(data["details"])
        else:
            self.details: str = None


class ReportDocumentEncryptionDetails:
    """
    Encryption details required for decryption of a report document's contents.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "standard" in data:
            self.standard: str = str(data["standard"])
        else:
            self.standard: str = None
        if "initializationVector" in data:
            self.initializationVector: str = str(data["initializationVector"])
        else:
            self.initializationVector: str = None
        if "key" in data:
            self.key: str = str(data["key"])
        else:
            self.key: str = None


class Report:
    """ """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "marketplaceIds" in data:
            self.marketplaceIds: _List[str] = [str(datum) for datum in data["marketplaceIds"]]
        else:
            self.marketplaceIds: _List[str] = []
        if "reportId" in data:
            self.reportId: str = str(data["reportId"])
        else:
            self.reportId: str = None
        if "reportType" in data:
            self.reportType: str = str(data["reportType"])
        else:
            self.reportType: str = None
        if "dataStartTime" in data:
            self.dataStartTime: str = str(data["dataStartTime"])
        else:
            self.dataStartTime: str = None
        if "dataEndTime" in data:
            self.dataEndTime: str = str(data["dataEndTime"])
        else:
            self.dataEndTime: str = None
        if "reportScheduleId" in data:
            self.reportScheduleId: str = str(data["reportScheduleId"])
        else:
            self.reportScheduleId: str = None
        if "createdTime" in data:
            self.createdTime: str = str(data["createdTime"])
        else:
            self.createdTime: str = None
        if "processingStatus" in data:
            self.processingStatus: str = str(data["processingStatus"])
        else:
            self.processingStatus: str = None
        if "processingStartTime" in data:
            self.processingStartTime: str = str(data["processingStartTime"])
        else:
            self.processingStartTime: str = None
        if "processingEndTime" in data:
            self.processingEndTime: str = str(data["processingEndTime"])
        else:
            self.processingEndTime: str = None
        if "reportDocumentId" in data:
            self.reportDocumentId: str = str(data["reportDocumentId"])
        else:
            self.reportDocumentId: str = None


class CreateReportScheduleSpecification:
    """ """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "reportType" in data:
            self.reportType: str = str(data["reportType"])
        else:
            self.reportType: str = None
        if "marketplaceIds" in data:
            self.marketplaceIds: _List[str] = [str(datum) for datum in data["marketplaceIds"]]
        else:
            self.marketplaceIds: _List[str] = []
        if "reportOptions" in data:
            self.reportOptions: ReportOptions = ReportOptions(data["reportOptions"])
        else:
            self.reportOptions: ReportOptions = None
        if "period" in data:
            self.period: str = str(data["period"])
        else:
            self.period: str = None
        if "nextReportCreationTime" in data:
            self.nextReportCreationTime: str = str(data["nextReportCreationTime"])
        else:
            self.nextReportCreationTime: str = None


class CreateReportSpecification:
    """ """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "reportOptions" in data:
            self.reportOptions: ReportOptions = ReportOptions(data["reportOptions"])
        else:
            self.reportOptions: ReportOptions = None
        if "reportType" in data:
            self.reportType: str = str(data["reportType"])
        else:
            self.reportType: str = None
        if "dataStartTime" in data:
            self.dataStartTime: str = str(data["dataStartTime"])
        else:
            self.dataStartTime: str = None
        if "dataEndTime" in data:
            self.dataEndTime: str = str(data["dataEndTime"])
        else:
            self.dataEndTime: str = None
        if "marketplaceIds" in data:
            self.marketplaceIds: _List[str] = [str(datum) for datum in data["marketplaceIds"]]
        else:
            self.marketplaceIds: _List[str] = []


class ReportOptions:
    """
    Additional information passed to reports. This varies by report type.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data


class ReportSchedule:
    """
    Detailed information about a report schedule.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "reportScheduleId" in data:
            self.reportScheduleId: str = str(data["reportScheduleId"])
        else:
            self.reportScheduleId: str = None
        if "reportType" in data:
            self.reportType: str = str(data["reportType"])
        else:
            self.reportType: str = None
        if "marketplaceIds" in data:
            self.marketplaceIds: _List[str] = [str(datum) for datum in data["marketplaceIds"]]
        else:
            self.marketplaceIds: _List[str] = []
        if "reportOptions" in data:
            self.reportOptions: ReportOptions = ReportOptions(data["reportOptions"])
        else:
            self.reportOptions: ReportOptions = None
        if "period" in data:
            self.period: str = str(data["period"])
        else:
            self.period: str = None
        if "nextReportCreationTime" in data:
            self.nextReportCreationTime: str = str(data["nextReportCreationTime"])
        else:
            self.nextReportCreationTime: str = None


class CreateReportResult:
    """ """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "reportId" in data:
            self.reportId: str = str(data["reportId"])
        else:
            self.reportId: str = None


class GetReportsResponse:
    """
    The response for the getReports operation.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "payload" in data:
            self.payload: ReportList = ReportList(data["payload"])
        else:
            self.payload: ReportList = None
        if "nextToken" in data:
            self.nextToken: str = str(data["nextToken"])
        else:
            self.nextToken: str = None
        if "errors" in data:
            self.errors: ErrorList = ErrorList(data["errors"])
        else:
            self.errors: ErrorList = None


class CreateReportResponse:
    """
    The response for the createReport operation.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "payload" in data:
            self.payload: CreateReportResult = CreateReportResult(data["payload"])
        else:
            self.payload: CreateReportResult = None
        if "errors" in data:
            self.errors: ErrorList = ErrorList(data["errors"])
        else:
            self.errors: ErrorList = None


class CancelReportResponse:
    """
    The response for the cancelReport operation.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "errors" in data:
            self.errors: ErrorList = ErrorList(data["errors"])
        else:
            self.errors: ErrorList = None


class CancelReportScheduleResponse:
    """
    The response for the cancelReportSchedule operation.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "errors" in data:
            self.errors: ErrorList = ErrorList(data["errors"])
        else:
            self.errors: ErrorList = None


class GetReportResponse:
    """
    The response for the getReport operation.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "payload" in data:
            self.payload: Report = Report(data["payload"])
        else:
            self.payload: Report = None
        if "errors" in data:
            self.errors: ErrorList = ErrorList(data["errors"])
        else:
            self.errors: ErrorList = None


class GetReportSchedulesResponse:
    """
    The response for the getReportSchedules operation.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "payload" in data:
            self.payload: ReportScheduleList = ReportScheduleList(data["payload"])
        else:
            self.payload: ReportScheduleList = None
        if "errors" in data:
            self.errors: ErrorList = ErrorList(data["errors"])
        else:
            self.errors: ErrorList = None


class GetReportScheduleResponse:
    """
    The response for the getReportSchedule operation.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "payload" in data:
            self.payload: ReportSchedule = ReportSchedule(data["payload"])
        else:
            self.payload: ReportSchedule = None
        if "errors" in data:
            self.errors: ErrorList = ErrorList(data["errors"])
        else:
            self.errors: ErrorList = None


class CreateReportScheduleResult:
    """ """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "reportScheduleId" in data:
            self.reportScheduleId: str = str(data["reportScheduleId"])
        else:
            self.reportScheduleId: str = None


class CreateReportScheduleResponse:
    """
    The response for the createReportSchedule operation.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "payload" in data:
            self.payload: CreateReportScheduleResult = CreateReportScheduleResult(data["payload"])
        else:
            self.payload: CreateReportScheduleResult = None
        if "errors" in data:
            self.errors: ErrorList = ErrorList(data["errors"])
        else:
            self.errors: ErrorList = None


class ReportDocument:
    """ """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "reportDocumentId" in data:
            self.reportDocumentId: str = str(data["reportDocumentId"])
        else:
            self.reportDocumentId: str = None
        if "url" in data:
            self.url: str = str(data["url"])
        else:
            self.url: str = None
        if "encryptionDetails" in data:
            self.encryptionDetails: ReportDocumentEncryptionDetails = ReportDocumentEncryptionDetails(
                data["encryptionDetails"]
            )
        else:
            self.encryptionDetails: ReportDocumentEncryptionDetails = None
        if "compressionAlgorithm" in data:
            self.compressionAlgorithm: str = str(data["compressionAlgorithm"])
        else:
            self.compressionAlgorithm: str = None


class GetReportDocumentResponse:
    """
    Response schema.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "payload" in data:
            self.payload: ReportDocument = ReportDocument(data["payload"])
        else:
            self.payload: ReportDocument = None
        if "errors" in data:
            self.errors: ErrorList = ErrorList(data["errors"])
        else:
            self.errors: ErrorList = None


class ErrorList(list, _List["Error"]):
    """
    A list of error responses returned when a request is unsuccessful.
    """

    def __init__(self, data):
        super().__init__([Error(datum) for datum in data])
        self.data = data


class ReportList(list, _List["Report"]):
    """ """

    def __init__(self, data):
        super().__init__([Report(datum) for datum in data])
        self.data = data


class ReportScheduleList(list, _List["ReportSchedule"]):
    """ """

    def __init__(self, data):
        super().__init__([ReportSchedule(datum) for datum in data])
        self.data = data


class Reports20200904Client(__BaseClient):
    """
        Returns report details for the reports that match the filters that you specify.
    **Usage Plan:**
    | Rate (requests per second) | Burst |
    | ---- | ---- |
    | 0.0222 | 10 |
    For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
    """

    def getReports(
        self,
        reportTypes: _List[str] = None,
        processingStatuses: _List[str] = None,
        marketplaceIds: _List[str] = None,
        pageSize: int = None,
        createdSince: str = None,
        createdUntil: str = None,
        nextToken: str = None,
    ):
        url = "/reports/2020-09-04/reports".format()
        params = {}
        if reportTypes is not None:
            params["reportTypes"] = ",".join(map(str, reportTypes))
        if processingStatuses is not None:
            params["processingStatuses"] = ",".join(map(str, processingStatuses))
        if marketplaceIds is not None:
            params["marketplaceIds"] = ",".join(map(str, marketplaceIds))
        if pageSize is not None:
            params["pageSize"] = pageSize
        if createdSince is not None:
            params["createdSince"] = createdSince
        if createdUntil is not None:
            params["createdUntil"] = createdUntil
        if nextToken is not None:
            params["nextToken"] = nextToken
        response = self.request(url, method="GET", params=params)
        return {
            200: GetReportsResponse,
            400: GetReportsResponse,
            401: GetReportsResponse,
            403: GetReportsResponse,
            404: GetReportsResponse,
            415: GetReportsResponse,
            429: GetReportsResponse,
            500: GetReportsResponse,
            503: GetReportsResponse,
        }[response.status_code](self._get_response_json(response))

    """
    Creates a report.
**Usage Plan:**
| Rate (requests per second) | Burst |
| ---- | ---- |
| 0.0167 | 15 |
For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
    """

    def createReport(
        self,
        data: CreateReportSpecification,
    ):
        url = "/reports/2020-09-04/reports".format()
        params = {}
        response = self.request(url, method="POST", data=params)
        return {
            202: CreateReportResponse,
            400: CreateReportResponse,
            401: CreateReportResponse,
            403: CreateReportResponse,
            404: CreateReportResponse,
            415: CreateReportResponse,
            429: CreateReportResponse,
            500: CreateReportResponse,
            503: CreateReportResponse,
        }[response.status_code](self._get_response_json(response))

    """
    Returns report details (including the reportDocumentId, if available) for the report that you specify.
**Usage Plan:**
| Rate (requests per second) | Burst |
| ---- | ---- |
| 2.0 | 15 |
For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
    """

    def getReport(
        self,
        reportId: str,
    ):
        url = "/reports/2020-09-04/reports/{reportId}".format(
            reportId=reportId,
        )
        params = {}
        response = self.request(url, method="GET", params=params)
        return {
            200: GetReportResponse,
            400: GetReportResponse,
            401: GetReportResponse,
            403: GetReportResponse,
            404: GetReportResponse,
            415: GetReportResponse,
            429: GetReportResponse,
            500: GetReportResponse,
            503: GetReportResponse,
        }[response.status_code](self._get_response_json(response))

    """
    Cancels the report that you specify. Only reports with processingStatus=IN_QUEUE can be cancelled. Cancelled reports are returned in subsequent calls to the getReport and getReports operations.
**Usage Plan:**
| Rate (requests per second) | Burst |
| ---- | ---- |
| 0.0222 | 10 |
For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
    """

    def cancelReport(
        self,
        reportId: str,
    ):
        url = "/reports/2020-09-04/reports/{reportId}".format(
            reportId=reportId,
        )
        params = {}
        response = self.request(url, method="DELETE", data=params)
        return {
            200: CancelReportResponse,
            400: CancelReportResponse,
            401: CancelReportResponse,
            403: CancelReportResponse,
            404: CancelReportResponse,
            415: CancelReportResponse,
            429: CancelReportResponse,
            500: CancelReportResponse,
            503: CancelReportResponse,
        }[response.status_code](self._get_response_json(response))

    """
    Returns report schedule details that match the filters that you specify.
**Usage Plan:**
| Rate (requests per second) | Burst |
| ---- | ---- |
| 0.0222 | 10 |
For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
    """

    def getReportSchedules(
        self,
        reportTypes: _List[str],
    ):
        url = "/reports/2020-09-04/schedules".format()
        params = {}
        if reportTypes is not None:
            params["reportTypes"] = ",".join(map(str, reportTypes))
        response = self.request(url, method="GET", params=params)
        return {
            200: GetReportSchedulesResponse,
            400: GetReportSchedulesResponse,
            401: GetReportSchedulesResponse,
            403: GetReportSchedulesResponse,
            404: GetReportSchedulesResponse,
            415: GetReportSchedulesResponse,
            429: GetReportSchedulesResponse,
            500: GetReportSchedulesResponse,
            503: GetReportSchedulesResponse,
        }[response.status_code](self._get_response_json(response))

    """
    Creates a report schedule. If a report schedule with the same report type and marketplace IDs already exists, it will be cancelled and replaced with this one.
**Usage Plan:**
| Rate (requests per second) | Burst |
| ---- | ---- |
| 0.0222 | 10 |
For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
    """

    def createReportSchedule(
        self,
        data: CreateReportScheduleSpecification,
    ):
        url = "/reports/2020-09-04/schedules".format()
        params = {}
        response = self.request(url, method="POST", data=params)
        return {
            201: CreateReportScheduleResponse,
            400: CreateReportScheduleResponse,
            401: CreateReportScheduleResponse,
            403: CreateReportScheduleResponse,
            404: CreateReportScheduleResponse,
            415: CreateReportScheduleResponse,
            429: CreateReportScheduleResponse,
            500: CreateReportScheduleResponse,
            503: CreateReportScheduleResponse,
        }[response.status_code](self._get_response_json(response))

    """
    Returns report schedule details for the report schedule that you specify.
**Usage Plan:**
| Rate (requests per second) | Burst |
| ---- | ---- |
| 0.0222 | 10 |
For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
    """

    def getReportSchedule(
        self,
        reportScheduleId: str,
    ):
        url = "/reports/2020-09-04/schedules/{reportScheduleId}".format(
            reportScheduleId=reportScheduleId,
        )
        params = {}
        response = self.request(url, method="GET", params=params)
        return {
            200: GetReportScheduleResponse,
            400: GetReportScheduleResponse,
            401: GetReportScheduleResponse,
            403: GetReportScheduleResponse,
            404: GetReportScheduleResponse,
            415: GetReportScheduleResponse,
            429: GetReportScheduleResponse,
            500: GetReportScheduleResponse,
            503: GetReportScheduleResponse,
        }[response.status_code](self._get_response_json(response))

    """
    Cancels the report schedule that you specify.
**Usage Plan:**
| Rate (requests per second) | Burst |
| ---- | ---- |
| 0.0222 | 10 |
For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
    """

    def cancelReportSchedule(
        self,
        reportScheduleId: str,
    ):
        url = "/reports/2020-09-04/schedules/{reportScheduleId}".format(
            reportScheduleId=reportScheduleId,
        )
        params = {}
        response = self.request(url, method="DELETE", data=params)
        return {
            200: CancelReportScheduleResponse,
            400: CancelReportScheduleResponse,
            401: CancelReportScheduleResponse,
            403: CancelReportScheduleResponse,
            404: CancelReportScheduleResponse,
            415: CancelReportScheduleResponse,
            429: CancelReportScheduleResponse,
            500: CancelReportScheduleResponse,
            503: CancelReportScheduleResponse,
        }[response.status_code](self._get_response_json(response))

    """
    Returns the information required for retrieving a report document's contents. This includes a presigned URL for the report document as well as the information required to decrypt the document's contents.
**Usage Plan:**
| Rate (requests per second) | Burst |
| ---- | ---- |
| 0.0167 | 15 |
For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
    """

    def getReportDocument(
        self,
        reportDocumentId: str,
    ):
        url = "/reports/2020-09-04/documents/{reportDocumentId}".format(
            reportDocumentId=reportDocumentId,
        )
        params = {}
        response = self.request(url, method="GET", params=params)
        return {
            200: GetReportDocumentResponse,
            400: GetReportDocumentResponse,
            401: GetReportDocumentResponse,
            403: GetReportDocumentResponse,
            404: GetReportDocumentResponse,
            415: GetReportDocumentResponse,
            429: GetReportDocumentResponse,
            500: GetReportDocumentResponse,
            503: GetReportDocumentResponse,
        }[response.status_code](self._get_response_json(response))



from dataclasses import dataclass
from typing import Dict, List


class MarketPlaces:
    """
    定义了亚马逊的所有渠道。
    
    不提供任何数据实例，所有操作均通过四个接口完成。
    """

    @dataclass
    class __Item:
        index: int
        country: str
        market_place: str
        endpoint: str

        @property
        def region(self):
            return {
                "https://sellingpartnerapi-na.amazon.com": "us-east-1",
                "https://sellingpartnerapi-fe.amazon.com": "us-west-2",
                "https://sellingpartnerapi-eu.amazon.com": "eu-west-1",
            }[self.endpoint]

        @property
        def oauth_endpoint(self):
            return {
                "https://sellingpartnerapi-na.amazon.com": "https://sellercentral.amazon.com",
                "https://sellingpartnerapi-fe.amazon.com": "https://sellercentral.amazon.com",
                "https://sellingpartnerapi-eu.amazon.com": "https://sellercentral-europe.amazon.com",
            }[self.endpoint]

        @property
        def sandbox_endpoint(self):
            return {
                "https://sellingpartnerapi-eu.amazon.com": 'https://sandbox.sellingpartnerapi-eu.amazon.com',
                "https://sellingpartnerapi-na.amazon.com": 'https://sandbox.sellingpartnerapi-na.amazon.com',
                "https://sellingpartnerapi-fe.amazon.com": 'https://sandbox.sellingpartnerapi-fe.amazon.com',
            }[self.endpoint]

    # Pay attention that the index will write to database and should not be edited!
    # The five digits:
    # 1:   amazon endpoint
    # 2-3: amazon market place
    # 4:   not set
    __data = {}
    for index, country, endpoint, market_place in (
            (101, "United Arab Emirates", "https://sellingpartnerapi-eu.amazon.com", "A2VIGQ35RCS4UG"),
            (102, "Germany", "https://sellingpartnerapi-eu.amazon.com", "A1PA6795UKMFR9"),
            (103, "Spain", "https://sellingpartnerapi-eu.amazon.com", "A1RKKUPIHCS9HS"),
            (104, "France", "https://sellingpartnerapi-eu.amazon.com", "A13V1IB3VIYZZH"),
            (105, "United Kingdom", "https://sellingpartnerapi-eu.amazon.com", "A1F83G8C2ARO7P"),
            (106, "India", "https://sellingpartnerapi-eu.amazon.com", "A21TJRUUN4KGV"),
            (107, "Italy", "https://sellingpartnerapi-eu.amazon.com", "APJ6JRA9NG5V4"),
            (108, "Netherlands", "https://sellingpartnerapi-eu.amazon.com", "A1805IZSGTT6HS"),
            (109, "Sweden", "https://sellingpartnerapi-eu.amazon.com", "A2NODRKZP88ZB9"),
            (110, "Turkey", "https://sellingpartnerapi-eu.amazon.com", "A33AVAJ2PDY3EV"),

            (201, "Australia", "https://sellingpartnerapi-fe.amazon.com", "A39IBJ37TRP1C6"),
            (202, "Japan", "https://sellingpartnerapi-fe.amazon.com", "A1VC38T7YXB528"),
            (203, "Singapore", "https://sellingpartnerapi-fe.amazon.com", "A19VAU5U5O7RUS"),

            (301, "United States of America", "https://sellingpartnerapi-na.amazon.com", "ATVPDKIKX0DER"),
            (302, "Brazil", "https://sellingpartnerapi-na.amazon.com", "A2Q3Y263D00KWC"),
            (303, "Canada", "https://sellingpartnerapi-na.amazon.com", "A2EUQ1WTGCTBG2"),
            (304, "Mexico", "https://sellingpartnerapi-na.amazon.com", "A1AM78C64UM0Y8"),
    ):
        __data[index] = __Item(index=index, country=country, market_place=market_place, endpoint=endpoint)

    __country_map: Dict[str, __Item] = {}
    __endpoint_map: Dict[str, List[__Item]] = {}
    __market_place_id_map: Dict[str, __Item] = {}

    # 这里采用lambda来规避命名空间的问题
    (lambda c, d: [c.setdefault(place.country, place) for place in d.values()])(__country_map, __data)
    (lambda m, d: [m.setdefault(place.market_place, place) for place in d.values()])(__market_place_id_map, __data)
    (lambda m, d: [m.setdefault(place.endpoint, []).append(place) for place in d.values()])(__endpoint_map, __data)

    def __init__(self):
        raise ValueError('这个类不可以实例化')

    @classmethod
    def all(cls):
        return cls.__data.values()

    @classmethod
    def get_by_index(cls, index: int):
        return cls.__data[index]

    @classmethod
    def get_by_country(cls, country: str):
        return cls.__country_map[country]

    @classmethod
    def get_by_endpoint(cls, endpoint: str):
        return cls.__endpoint_map[endpoint]

    @classmethod
    def get_by_market_place_id(cls, market_place_id: str):
        return cls.__market_place_id_map[market_place_id]



from .base import BaseClient as __BaseClient, convert_bool
from typing import List as _List


class ErrorList:
    """
    A list of error responses returned when a request is unsuccessful.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "errors" in data:
            self.errors: _List[Error] = [Error(datum) for datum in data["errors"]]
        else:
            self.errors: _List[Error] = []


class Error:
    """
    Error response returned when the request is unsuccessful.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "code" in data:
            self.code: str = str(data["code"])
        else:
            self.code: str = None
        if "message" in data:
            self.message: str = str(data["message"])
        else:
            self.message: str = None
        if "details" in data:
            self.details: str = str(data["details"])
        else:
            self.details: str = None


class Report:
    """
    Detailed information about the report.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "marketplaceIds" in data:
            self.marketplaceIds: _List[str] = [str(datum) for datum in data["marketplaceIds"]]
        else:
            self.marketplaceIds: _List[str] = []
        if "reportId" in data:
            self.reportId: str = str(data["reportId"])
        else:
            self.reportId: str = None
        if "reportType" in data:
            self.reportType: str = str(data["reportType"])
        else:
            self.reportType: str = None
        if "dataStartTime" in data:
            self.dataStartTime: str = str(data["dataStartTime"])
        else:
            self.dataStartTime: str = None
        if "dataEndTime" in data:
            self.dataEndTime: str = str(data["dataEndTime"])
        else:
            self.dataEndTime: str = None
        if "reportScheduleId" in data:
            self.reportScheduleId: str = str(data["reportScheduleId"])
        else:
            self.reportScheduleId: str = None
        if "createdTime" in data:
            self.createdTime: str = str(data["createdTime"])
        else:
            self.createdTime: str = None
        if "processingStatus" in data:
            self.processingStatus: str = str(data["processingStatus"])
        else:
            self.processingStatus: str = None
        if "processingStartTime" in data:
            self.processingStartTime: str = str(data["processingStartTime"])
        else:
            self.processingStartTime: str = None
        if "processingEndTime" in data:
            self.processingEndTime: str = str(data["processingEndTime"])
        else:
            self.processingEndTime: str = None
        if "reportDocumentId" in data:
            self.reportDocumentId: str = str(data["reportDocumentId"])
        else:
            self.reportDocumentId: str = None


class CreateReportScheduleSpecification:
    """ """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "reportType" in data:
            self.reportType: str = str(data["reportType"])
        else:
            self.reportType: str = None
        if "marketplaceIds" in data:
            self.marketplaceIds: _List[str] = [str(datum) for datum in data["marketplaceIds"]]
        else:
            self.marketplaceIds: _List[str] = []
        if "reportOptions" in data:
            self.reportOptions: ReportOptions = ReportOptions(data["reportOptions"])
        else:
            self.reportOptions: ReportOptions = None
        if "period" in data:
            self.period: str = str(data["period"])
        else:
            self.period: str = None
        if "nextReportCreationTime" in data:
            self.nextReportCreationTime: str = str(data["nextReportCreationTime"])
        else:
            self.nextReportCreationTime: str = None


class CreateReportSpecification:
    """
    Information required to create the report.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "reportOptions" in data:
            self.reportOptions: ReportOptions = ReportOptions(data["reportOptions"])
        else:
            self.reportOptions: ReportOptions = None
        if "reportType" in data:
            self.reportType: str = str(data["reportType"])
        else:
            self.reportType: str = None
        if "dataStartTime" in data:
            self.dataStartTime: str = str(data["dataStartTime"])
        else:
            self.dataStartTime: str = None
        if "dataEndTime" in data:
            self.dataEndTime: str = str(data["dataEndTime"])
        else:
            self.dataEndTime: str = None
        if "marketplaceIds" in data:
            self.marketplaceIds: _List[str] = [str(datum) for datum in data["marketplaceIds"]]
        else:
            self.marketplaceIds: _List[str] = []


class ReportOptions:
    """
    Additional information passed to reports. This varies by report type.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data


class ReportSchedule:
    """
    Detailed information about a report schedule.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "reportScheduleId" in data:
            self.reportScheduleId: str = str(data["reportScheduleId"])
        else:
            self.reportScheduleId: str = None
        if "reportType" in data:
            self.reportType: str = str(data["reportType"])
        else:
            self.reportType: str = None
        if "marketplaceIds" in data:
            self.marketplaceIds: _List[str] = [str(datum) for datum in data["marketplaceIds"]]
        else:
            self.marketplaceIds: _List[str] = []
        if "reportOptions" in data:
            self.reportOptions: ReportOptions = ReportOptions(data["reportOptions"])
        else:
            self.reportOptions: ReportOptions = None
        if "period" in data:
            self.period: str = str(data["period"])
        else:
            self.period: str = None
        if "nextReportCreationTime" in data:
            self.nextReportCreationTime: str = str(data["nextReportCreationTime"])
        else:
            self.nextReportCreationTime: str = None


class ReportScheduleList:
    """
    A list of report schedules.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "reportSchedules" in data:
            self.reportSchedules: _List[ReportSchedule] = [ReportSchedule(datum) for datum in data["reportSchedules"]]
        else:
            self.reportSchedules: _List[ReportSchedule] = []


class CreateReportResponse:
    """
    Response schema.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "reportId" in data:
            self.reportId: str = str(data["reportId"])
        else:
            self.reportId: str = None


class GetReportsResponse:
    """
    The response for the getReports operation.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "reports" in data:
            self.reports: ReportList = ReportList(data["reports"])
        else:
            self.reports: ReportList = None
        if "nextToken" in data:
            self.nextToken: str = str(data["nextToken"])
        else:
            self.nextToken: str = None


class CreateReportScheduleResponse:
    """
    Response schema.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "reportScheduleId" in data:
            self.reportScheduleId: str = str(data["reportScheduleId"])
        else:
            self.reportScheduleId: str = None


class ReportDocument:
    """
    Information required for the report document.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "reportDocumentId" in data:
            self.reportDocumentId: str = str(data["reportDocumentId"])
        else:
            self.reportDocumentId: str = None
        if "url" in data:
            self.url: str = str(data["url"])
        else:
            self.url: str = None
        if "compressionAlgorithm" in data:
            self.compressionAlgorithm: str = str(data["compressionAlgorithm"])
        else:
            self.compressionAlgorithm: str = None


class ReportList(list, _List["Report"]):
    """
    A list of reports.
    """

    def __init__(self, data):
        super().__init__([Report(datum) for datum in data])
        self.data = data


class Reports20210630Client(__BaseClient):
    """
        Returns report details for the reports that match the filters that you specify.
    **Usage Plan:**
    | Rate (requests per second) | Burst |
    | ---- | ---- |
    | 0.0222 | 10 |
    For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
    """

    def getReports(
        self,
        reportTypes: _List[str] = None,
        processingStatuses: _List[str] = None,
        marketplaceIds: _List[str] = None,
        pageSize: int = None,
        createdSince: str = None,
        createdUntil: str = None,
        nextToken: str = None,
    ):
        url = "/reports/2021-06-30/reports".format()
        params = {}
        if reportTypes is not None:
            params["reportTypes"] = ",".join(map(str, reportTypes))
        if processingStatuses is not None:
            params["processingStatuses"] = ",".join(map(str, processingStatuses))
        if marketplaceIds is not None:
            params["marketplaceIds"] = ",".join(map(str, marketplaceIds))
        if pageSize is not None:
            params["pageSize"] = pageSize
        if createdSince is not None:
            params["createdSince"] = createdSince
        if createdUntil is not None:
            params["createdUntil"] = createdUntil
        if nextToken is not None:
            params["nextToken"] = nextToken
        response = self.request(url, method="GET", params=params)
        return {
            200: GetReportsResponse,
            400: ErrorList,
            401: ErrorList,
            403: ErrorList,
            404: ErrorList,
            415: ErrorList,
            429: ErrorList,
            500: ErrorList,
            503: ErrorList,
        }[response.status_code](self._get_response_json(response))

    """
    Creates a report.
**Usage Plan:**
| Rate (requests per second) | Burst |
| ---- | ---- |
| 0.0167 | 15 |
For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
    """

    def createReport(
        self,
        data: CreateReportSpecification,
    ):
        url = "/reports/2021-06-30/reports".format()
        params = {}
        response = self.request(url, method="POST", data=params)
        return {
            202: CreateReportResponse,
            400: ErrorList,
            401: ErrorList,
            403: ErrorList,
            404: ErrorList,
            415: ErrorList,
            429: ErrorList,
            500: ErrorList,
            503: ErrorList,
        }[response.status_code](self._get_response_json(response))

    """
    Returns report details (including the reportDocumentId, if available) for the report that you specify.
**Usage Plan:**
| Rate (requests per second) | Burst |
| ---- | ---- |
| 2.0 | 15 |
For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
    """

    def getReport(
        self,
        reportId: str,
    ):
        url = "/reports/2021-06-30/reports/{reportId}".format(
            reportId=reportId,
        )
        params = {}
        response = self.request(url, method="GET", params=params)
        return {
            200: Report,
            400: ErrorList,
            401: ErrorList,
            403: ErrorList,
            404: ErrorList,
            415: ErrorList,
            429: ErrorList,
            500: ErrorList,
            503: ErrorList,
        }[response.status_code](self._get_response_json(response))

    """
    Cancels the report that you specify. Only reports with processingStatus=IN_QUEUE can be cancelled. Cancelled reports are returned in subsequent calls to the getReport and getReports operations.
**Usage Plan:**
| Rate (requests per second) | Burst |
| ---- | ---- |
| 0.0222 | 10 |
For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
    """

    def cancelReport(
        self,
        reportId: str,
    ):
        url = "/reports/2021-06-30/reports/{reportId}".format(
            reportId=reportId,
        )
        params = {}
        response = self.request(url, method="DELETE", data=params)
        return {
            400: ErrorList,
            401: ErrorList,
            403: ErrorList,
            404: ErrorList,
            415: ErrorList,
            429: ErrorList,
            500: ErrorList,
            503: ErrorList,
        }[response.status_code](self._get_response_json(response))

    """
    Returns report schedule details that match the filters that you specify.
**Usage Plan:**
| Rate (requests per second) | Burst |
| ---- | ---- |
| 0.0222 | 10 |
For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
    """

    def getReportSchedules(
        self,
        reportTypes: _List[str],
    ):
        url = "/reports/2021-06-30/schedules".format()
        params = {}
        if reportTypes is not None:
            params["reportTypes"] = ",".join(map(str, reportTypes))
        response = self.request(url, method="GET", params=params)
        return {
            200: ReportScheduleList,
            400: ErrorList,
            401: ErrorList,
            403: ErrorList,
            404: ErrorList,
            415: ErrorList,
            429: ErrorList,
            500: ErrorList,
            503: ErrorList,
        }[response.status_code](self._get_response_json(response))

    """
    Creates a report schedule. If a report schedule with the same report type and marketplace IDs already exists, it will be cancelled and replaced with this one.
**Usage Plan:**
| Rate (requests per second) | Burst |
| ---- | ---- |
| 0.0222 | 10 |
For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
    """

    def createReportSchedule(
        self,
        data: CreateReportScheduleSpecification,
    ):
        url = "/reports/2021-06-30/schedules".format()
        params = {}
        response = self.request(url, method="POST", data=params)
        return {
            201: CreateReportScheduleResponse,
            400: ErrorList,
            401: ErrorList,
            403: ErrorList,
            404: ErrorList,
            415: ErrorList,
            429: ErrorList,
            500: ErrorList,
            503: ErrorList,
        }[response.status_code](self._get_response_json(response))

    """
    Returns report schedule details for the report schedule that you specify.
**Usage Plan:**
| Rate (requests per second) | Burst |
| ---- | ---- |
| 0.0222 | 10 |
For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
    """

    def getReportSchedule(
        self,
        reportScheduleId: str,
    ):
        url = "/reports/2021-06-30/schedules/{reportScheduleId}".format(
            reportScheduleId=reportScheduleId,
        )
        params = {}
        response = self.request(url, method="GET", params=params)
        return {
            200: ReportSchedule,
            400: ErrorList,
            401: ErrorList,
            403: ErrorList,
            404: ErrorList,
            415: ErrorList,
            429: ErrorList,
            500: ErrorList,
            503: ErrorList,
        }[response.status_code](self._get_response_json(response))

    """
    Cancels the report schedule that you specify.
**Usage Plan:**
| Rate (requests per second) | Burst |
| ---- | ---- |
| 0.0222 | 10 |
For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
    """

    def cancelReportSchedule(
        self,
        reportScheduleId: str,
    ):
        url = "/reports/2021-06-30/schedules/{reportScheduleId}".format(
            reportScheduleId=reportScheduleId,
        )
        params = {}
        response = self.request(url, method="DELETE", data=params)
        return {
            400: ErrorList,
            401: ErrorList,
            403: ErrorList,
            404: ErrorList,
            415: ErrorList,
            429: ErrorList,
            500: ErrorList,
            503: ErrorList,
        }[response.status_code](self._get_response_json(response))

    """
    Returns the information required for retrieving a report document's contents.
**Usage Plan:**
| Rate (requests per second) | Burst |
| ---- | ---- |
| 0.0167 | 15 |
For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
    """

    def getReportDocument(
        self,
        reportDocumentId: str,
    ):
        url = "/reports/2021-06-30/documents/{reportDocumentId}".format(
            reportDocumentId=reportDocumentId,
        )
        params = {}
        response = self.request(url, method="GET", params=params)
        return {
            200: ReportDocument,
            400: ErrorList,
            401: ErrorList,
            403: ErrorList,
            404: ErrorList,
            415: ErrorList,
            429: ErrorList,
            500: ErrorList,
            503: ErrorList,
        }[response.status_code](self._get_response_json(response))



from .vendor_transaction_status_v1 import VendorTransactionStatusV1Client
from .vendor_shipments_v1 import VendorShipmentsV1Client
from .vendor_orders_v1 import VendorOrdersV1Client
from .vendor_invoices_v1 import VendorInvoicesV1Client
from .vendor_direct_fulfillment_transactions_v1 import VendorDirectFulfillmentTransactionsV1Client
from .vendor_direct_fulfillment_shipping_v1 import VendorDirectFulfillmentShippingV1Client
from .vendor_direct_fulfillment_payments_v1 import VendorDirectFulfillmentPaymentsV1Client
from .vendor_direct_fulfillment_orders_v1 import VendorDirectFulfillmentOrdersV1Client
from .vendor_direct_fulfillment_inventory_v1 import VendorDirectFulfillmentInventoryV1Client
from .uploads_2020_11_01 import Uploads20201101Client
from .tokens_2021_03_01 import Tokens20210301Client
from .solicitations_v1 import SolicitationsV1Client
from .shipping_v1 import ShippingV1Client
from .shipment_invoicing_v0 import ShipmentInvoicingV0Client
from .services_v1 import ServicesV1Client
from .sellers_v1 import SellersV1Client
from .sales_v1 import SalesV1Client
from .reports_2021_06_30 import Reports20210630Client
from .reports_2020_09_04 import Reports20200904Client
from .product_type_definitions_2020_09_01 import ProductTypeDefinitions20200901Client
from .product_pricing_v0 import ProductPricingV0Client
from .product_fees_v0 import ProductFeesV0Client
from .orders_v0 import OrdersV0Client
from .notifications_v1 import NotificationsV1Client
from .messaging_v1 import MessagingV1Client
from .merchant_fulfillment_v0 import MerchantFulfillmentV0Client
from .listings_restrictions_2021_08_01 import ListingsRestrictions20210801Client
from .listings_items_2021_08_01 import ListingsItems20210801Client
from .listings_items_2020_09_01 import ListingsItems20200901Client
from .fulfillment_outbound_2020_07_01 import FulfillmentOutbound20200701Client
from .fulfillment_inbound_v0 import FulfillmentInboundV0Client
from .finances_v0 import FinancesV0Client
from .feeds_2021_06_30 import Feeds20210630Client
from .feeds_2020_09_04 import Feeds20200904Client
from .fba_small_and_light_v1 import FbaSmallAndLightV1Client
from .fba_inventory_v1 import FbaInventoryV1Client
from .fba_inbound_eligibility_v1 import FbaInboundEligibilityV1Client
from .catalog_items_v0 import CatalogItemsV0Client
from .catalog_items_2020_12_01 import CatalogItems20201201Client
from .authorization_v1 import AuthorizationV1Client
from .aplus_content_2020_11_01 import AplusContent20201101Client
from .marketplaces import MarketPlaces
from .report_types import ReportType, ReportTypeGroup

version = "1.7.1"
name = "amazon-sp-api-clients"
author = "Haoyu Pan"
author_email = "panhaoyu.china@outlook.com"
description = "Amazon selling partner api clients."
url = "https://github.com/panhaoyu/sp-api-clients"



from .base import BaseClient as __BaseClient, convert_bool
from typing import List as _List


class Error:
    """
    An error response returned when the request is unsuccessful.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "code" in data:
            self.code: str = str(data["code"])
        else:
            self.code: str = None
        if "message" in data:
            self.message: str = str(data["message"])
        else:
            self.message: str = None
        if "details" in data:
            self.details: str = str(data["details"])
        else:
            self.details: str = None


class CancelFeedResponse:
    """
    Response schema.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "errors" in data:
            self.errors: ErrorList = ErrorList(data["errors"])
        else:
            self.errors: ErrorList = None


class CreateFeedResult:
    """ """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "feedId" in data:
            self.feedId: str = str(data["feedId"])
        else:
            self.feedId: str = None


class Feed:
    """ """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "feedId" in data:
            self.feedId: str = str(data["feedId"])
        else:
            self.feedId: str = None
        if "feedType" in data:
            self.feedType: str = str(data["feedType"])
        else:
            self.feedType: str = None
        if "marketplaceIds" in data:
            self.marketplaceIds: _List[str] = [str(datum) for datum in data["marketplaceIds"]]
        else:
            self.marketplaceIds: _List[str] = []
        if "createdTime" in data:
            self.createdTime: str = str(data["createdTime"])
        else:
            self.createdTime: str = None
        if "processingStatus" in data:
            self.processingStatus: str = str(data["processingStatus"])
        else:
            self.processingStatus: str = None
        if "processingStartTime" in data:
            self.processingStartTime: str = str(data["processingStartTime"])
        else:
            self.processingStartTime: str = None
        if "processingEndTime" in data:
            self.processingEndTime: str = str(data["processingEndTime"])
        else:
            self.processingEndTime: str = None
        if "resultFeedDocumentId" in data:
            self.resultFeedDocumentId: str = str(data["resultFeedDocumentId"])
        else:
            self.resultFeedDocumentId: str = None


class GetFeedsResponse:
    """
    Response schema.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "payload" in data:
            self.payload: FeedList = FeedList(data["payload"])
        else:
            self.payload: FeedList = None
        if "nextToken" in data:
            self.nextToken: str = str(data["nextToken"])
        else:
            self.nextToken: str = None
        if "errors" in data:
            self.errors: ErrorList = ErrorList(data["errors"])
        else:
            self.errors: ErrorList = None


class GetFeedResponse:
    """
    Response schema.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "payload" in data:
            self.payload: Feed = Feed(data["payload"])
        else:
            self.payload: Feed = None
        if "errors" in data:
            self.errors: ErrorList = ErrorList(data["errors"])
        else:
            self.errors: ErrorList = None


class FeedDocumentEncryptionDetails:
    """
    Encryption details for required client-side encryption and decryption of document contents.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "standard" in data:
            self.standard: str = str(data["standard"])
        else:
            self.standard: str = None
        if "initializationVector" in data:
            self.initializationVector: str = str(data["initializationVector"])
        else:
            self.initializationVector: str = None
        if "key" in data:
            self.key: str = str(data["key"])
        else:
            self.key: str = None


class FeedDocument:
    """ """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "feedDocumentId" in data:
            self.feedDocumentId: str = str(data["feedDocumentId"])
        else:
            self.feedDocumentId: str = None
        if "url" in data:
            self.url: str = str(data["url"])
        else:
            self.url: str = None
        if "encryptionDetails" in data:
            self.encryptionDetails: FeedDocumentEncryptionDetails = FeedDocumentEncryptionDetails(
                data["encryptionDetails"]
            )
        else:
            self.encryptionDetails: FeedDocumentEncryptionDetails = None
        if "compressionAlgorithm" in data:
            self.compressionAlgorithm: str = str(data["compressionAlgorithm"])
        else:
            self.compressionAlgorithm: str = None


class GetFeedDocumentResponse:
    """
    Response schema.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "payload" in data:
            self.payload: FeedDocument = FeedDocument(data["payload"])
        else:
            self.payload: FeedDocument = None
        if "errors" in data:
            self.errors: ErrorList = ErrorList(data["errors"])
        else:
            self.errors: ErrorList = None


class CreateFeedResponse:
    """
    Response schema.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "payload" in data:
            self.payload: CreateFeedResult = CreateFeedResult(data["payload"])
        else:
            self.payload: CreateFeedResult = None
        if "errors" in data:
            self.errors: ErrorList = ErrorList(data["errors"])
        else:
            self.errors: ErrorList = None


class FeedOptions:
    """
    Additional options to control the feed. These vary by feed type.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data


class CreateFeedSpecification:
    """ """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "feedType" in data:
            self.feedType: str = str(data["feedType"])
        else:
            self.feedType: str = None
        if "marketplaceIds" in data:
            self.marketplaceIds: _List[str] = [str(datum) for datum in data["marketplaceIds"]]
        else:
            self.marketplaceIds: _List[str] = []
        if "inputFeedDocumentId" in data:
            self.inputFeedDocumentId: str = str(data["inputFeedDocumentId"])
        else:
            self.inputFeedDocumentId: str = None
        if "feedOptions" in data:
            self.feedOptions: FeedOptions = FeedOptions(data["feedOptions"])
        else:
            self.feedOptions: FeedOptions = None


class CreateFeedDocumentSpecification:
    """ """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "contentType" in data:
            self.contentType: str = str(data["contentType"])
        else:
            self.contentType: str = None


class CreateFeedDocumentResponse:
    """
    The response for the createFeedDocument operation.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "payload" in data:
            self.payload: CreateFeedDocumentResult = CreateFeedDocumentResult(data["payload"])
        else:
            self.payload: CreateFeedDocumentResult = None
        if "errors" in data:
            self.errors: ErrorList = ErrorList(data["errors"])
        else:
            self.errors: ErrorList = None


class CreateFeedDocumentResult:
    """
    Information required to encrypt and upload a feed document's contents.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "feedDocumentId" in data:
            self.feedDocumentId: str = str(data["feedDocumentId"])
        else:
            self.feedDocumentId: str = None
        if "url" in data:
            self.url: str = str(data["url"])
        else:
            self.url: str = None
        if "encryptionDetails" in data:
            self.encryptionDetails: FeedDocumentEncryptionDetails = FeedDocumentEncryptionDetails(
                data["encryptionDetails"]
            )
        else:
            self.encryptionDetails: FeedDocumentEncryptionDetails = None


class ErrorList(list, _List["Error"]):
    """
    A list of error responses returned when a request is unsuccessful.
    """

    def __init__(self, data):
        super().__init__([Error(datum) for datum in data])
        self.data = data


class FeedList(list, _List["Feed"]):
    """ """

    def __init__(self, data):
        super().__init__([Feed(datum) for datum in data])
        self.data = data


class Feeds20200904Client(__BaseClient):
    """
        Returns feed details for the feeds that match the filters that you specify.
    **Usage Plan:**
    | Rate (requests per second) | Burst |
    | ---- | ---- |
    | 0.0222 | 10 |
    For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
    """

    def getFeeds(
        self,
        feedTypes: _List[str] = None,
        marketplaceIds: _List[str] = None,
        pageSize: int = None,
        processingStatuses: _List[str] = None,
        createdSince: str = None,
        createdUntil: str = None,
        nextToken: str = None,
    ):
        url = "/feeds/2020-09-04/feeds".format()
        params = {}
        if feedTypes is not None:
            params["feedTypes"] = ",".join(map(str, feedTypes))
        if marketplaceIds is not None:
            params["marketplaceIds"] = ",".join(map(str, marketplaceIds))
        if pageSize is not None:
            params["pageSize"] = pageSize
        if processingStatuses is not None:
            params["processingStatuses"] = ",".join(map(str, processingStatuses))
        if createdSince is not None:
            params["createdSince"] = createdSince
        if createdUntil is not None:
            params["createdUntil"] = createdUntil
        if nextToken is not None:
            params["nextToken"] = nextToken
        response = self.request(url, method="GET", params=params)
        return {
            200: GetFeedsResponse,
            400: GetFeedsResponse,
            401: GetFeedsResponse,
            403: GetFeedsResponse,
            404: GetFeedsResponse,
            415: GetFeedsResponse,
            429: GetFeedsResponse,
            500: GetFeedsResponse,
            503: GetFeedsResponse,
        }[response.status_code](self._get_response_json(response))

    """
    Creates a feed. Encrypt and upload the contents of the feed document before calling this operation.
**Usage Plan:**
| Rate (requests per second) | Burst |
| ---- | ---- |
| 0.0083 | 15 |
For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
    """

    def createFeed(
        self,
        data: CreateFeedSpecification,
    ):
        url = "/feeds/2020-09-04/feeds".format()
        params = {}
        response = self.request(url, method="POST", data=params)
        return {
            202: CreateFeedResponse,
            400: CreateFeedResponse,
            401: CreateFeedResponse,
            403: CreateFeedResponse,
            404: CreateFeedResponse,
            415: CreateFeedResponse,
            429: CreateFeedResponse,
            500: CreateFeedResponse,
            503: CreateFeedResponse,
        }[response.status_code](self._get_response_json(response))

    """
    Returns feed details (including the resultDocumentId, if available) for the feed that you specify.
**Usage Plan:**
| Rate (requests per second) | Burst |
| ---- | ---- |
| 2.0 | 15 |
For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
    """

    def getFeed(
        self,
        feedId: str,
    ):
        url = "/feeds/2020-09-04/feeds/{feedId}".format(
            feedId=feedId,
        )
        params = {}
        response = self.request(url, method="GET", params=params)
        return {
            200: GetFeedResponse,
            400: GetFeedResponse,
            401: GetFeedResponse,
            403: GetFeedResponse,
            404: GetFeedResponse,
            415: GetFeedResponse,
            429: GetFeedResponse,
            500: GetFeedResponse,
            503: GetFeedResponse,
        }[response.status_code](self._get_response_json(response))

    """
    Cancels the feed that you specify. Only feeds with processingStatus=IN_QUEUE can be cancelled. Cancelled feeds are returned in subsequent calls to the getFeed and getFeeds operations.
**Usage Plan:**
| Rate (requests per second) | Burst |
| ---- | ---- |
| 0.0222 | 10 |
For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
    """

    def cancelFeed(
        self,
        feedId: str,
    ):
        url = "/feeds/2020-09-04/feeds/{feedId}".format(
            feedId=feedId,
        )
        params = {}
        response = self.request(url, method="DELETE", data=params)
        return {
            200: CancelFeedResponse,
            400: CancelFeedResponse,
            401: CancelFeedResponse,
            403: CancelFeedResponse,
            404: CancelFeedResponse,
            415: CancelFeedResponse,
            429: CancelFeedResponse,
            500: CancelFeedResponse,
            503: CancelFeedResponse,
        }[response.status_code](self._get_response_json(response))

    """
    Creates a feed document for the feed type that you specify. This operation returns encryption details for encrypting the contents of the document, as well as a presigned URL for uploading the encrypted feed document contents. It also returns a feedDocumentId value that you can pass in with a subsequent call to the createFeed operation.
**Usage Plan:**
| Rate (requests per second) | Burst |
| ---- | ---- |
| 0.0083 | 15 |
For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
    """

    def createFeedDocument(
        self,
        data: CreateFeedDocumentSpecification,
    ):
        url = "/feeds/2020-09-04/documents".format()
        params = {}
        response = self.request(url, method="POST", data=params)
        return {
            201: CreateFeedDocumentResponse,
            400: CreateFeedDocumentResponse,
            403: CreateFeedDocumentResponse,
            404: CreateFeedDocumentResponse,
            413: CreateFeedDocumentResponse,
            415: CreateFeedDocumentResponse,
            429: CreateFeedDocumentResponse,
            500: CreateFeedDocumentResponse,
            503: CreateFeedDocumentResponse,
        }[response.status_code](self._get_response_json(response))

    """
    Returns the information required for retrieving a feed document's contents. This includes a presigned URL for the feed document as well as the information required to decrypt the document's contents.
**Usage Plan:**
| Rate (requests per second) | Burst |
| ---- | ---- |
| 0.0222 | 10 |
For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
    """

    def getFeedDocument(
        self,
        feedDocumentId: str,
    ):
        url = "/feeds/2020-09-04/documents/{feedDocumentId}".format(
            feedDocumentId=feedDocumentId,
        )
        params = {}
        response = self.request(url, method="GET", params=params)
        return {
            200: GetFeedDocumentResponse,
            400: GetFeedDocumentResponse,
            401: GetFeedDocumentResponse,
            403: GetFeedDocumentResponse,
            404: GetFeedDocumentResponse,
            415: GetFeedDocumentResponse,
            429: GetFeedDocumentResponse,
            500: GetFeedDocumentResponse,
            503: GetFeedDocumentResponse,
        }[response.status_code](self._get_response_json(response))



from .base import BaseClient as __BaseClient, convert_bool
from typing import List as _List


class Error:
    """
    Error response returned when the request is unsuccessful.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "code" in data:
            self.code: str = str(data["code"])
        else:
            self.code: str = None
        if "message" in data:
            self.message: str = str(data["message"])
        else:
            self.message: str = None
        if "details" in data:
            self.details: str = str(data["details"])
        else:
            self.details: str = None


class LabelFormatOptionRequest:
    """
    Whether to include a packing slip.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "IncludePackingSlipWithLabel" in data:
            self.IncludePackingSlipWithLabel: bool = convert_bool(data["IncludePackingSlipWithLabel"])
        else:
            self.IncludePackingSlipWithLabel: bool = None


class LabelFormatOption:
    """
    The label format details and whether to include a packing slip.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "IncludePackingSlipWithLabel" in data:
            self.IncludePackingSlipWithLabel: bool = convert_bool(data["IncludePackingSlipWithLabel"])
        else:
            self.IncludePackingSlipWithLabel: bool = None
        if "LabelFormat" in data:
            self.LabelFormat: LabelFormat = LabelFormat(data["LabelFormat"])
        else:
            self.LabelFormat: LabelFormat = None


class AvailableCarrierWillPickUpOption:
    """
    Indicates whether the carrier will pick up the package, and what fee is charged, if any.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "CarrierWillPickUpOption" in data:
            self.CarrierWillPickUpOption: CarrierWillPickUpOption = CarrierWillPickUpOption(
                data["CarrierWillPickUpOption"]
            )
        else:
            self.CarrierWillPickUpOption: CarrierWillPickUpOption = None
        if "Charge" in data:
            self.Charge: CurrencyAmount = CurrencyAmount(data["Charge"])
        else:
            self.Charge: CurrencyAmount = None


class AvailableDeliveryExperienceOption:
    """
    The available delivery confirmation options, and the fee charged, if any.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "DeliveryExperienceOption" in data:
            self.DeliveryExperienceOption: DeliveryExperienceOption = DeliveryExperienceOption(
                data["DeliveryExperienceOption"]
            )
        else:
            self.DeliveryExperienceOption: DeliveryExperienceOption = None
        if "Charge" in data:
            self.Charge: CurrencyAmount = CurrencyAmount(data["Charge"])
        else:
            self.Charge: CurrencyAmount = None


class AvailableShippingServiceOptions:
    """
    The available shipping service options.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "AvailableCarrierWillPickUpOptions" in data:
            self.AvailableCarrierWillPickUpOptions: AvailableCarrierWillPickUpOptionsList = (
                AvailableCarrierWillPickUpOptionsList(data["AvailableCarrierWillPickUpOptions"])
            )
        else:
            self.AvailableCarrierWillPickUpOptions: AvailableCarrierWillPickUpOptionsList = None
        if "AvailableDeliveryExperienceOptions" in data:
            self.AvailableDeliveryExperienceOptions: AvailableDeliveryExperienceOptionsList = (
                AvailableDeliveryExperienceOptionsList(data["AvailableDeliveryExperienceOptions"])
            )
        else:
            self.AvailableDeliveryExperienceOptions: AvailableDeliveryExperienceOptionsList = None


class Constraint:
    """
    A validation constraint.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "ValidationRegEx" in data:
            self.ValidationRegEx: str = str(data["ValidationRegEx"])
        else:
            self.ValidationRegEx: str = None
        if "ValidationString" in data:
            self.ValidationString: str = str(data["ValidationString"])
        else:
            self.ValidationString: str = None


class AdditionalInputs:
    """
    Maps the additional seller input to the definition. The key to the map is the field name.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "AdditionalInputFieldName" in data:
            self.AdditionalInputFieldName: str = str(data["AdditionalInputFieldName"])
        else:
            self.AdditionalInputFieldName: str = None
        if "SellerInputDefinition" in data:
            self.SellerInputDefinition: SellerInputDefinition = SellerInputDefinition(data["SellerInputDefinition"])
        else:
            self.SellerInputDefinition: SellerInputDefinition = None


class SellerInputDefinition:
    """
    Specifies characteristics that apply to a seller input.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "IsRequired" in data:
            self.IsRequired: bool = convert_bool(data["IsRequired"])
        else:
            self.IsRequired: bool = None
        if "DataType" in data:
            self.DataType: str = str(data["DataType"])
        else:
            self.DataType: str = None
        if "Constraints" in data:
            self.Constraints: Constraints = Constraints(data["Constraints"])
        else:
            self.Constraints: Constraints = None
        if "InputDisplayText" in data:
            self.InputDisplayText: str = str(data["InputDisplayText"])
        else:
            self.InputDisplayText: str = None
        if "InputTarget" in data:
            self.InputTarget: InputTargetType = InputTargetType(data["InputTarget"])
        else:
            self.InputTarget: InputTargetType = None
        if "StoredValue" in data:
            self.StoredValue: AdditionalSellerInput = AdditionalSellerInput(data["StoredValue"])
        else:
            self.StoredValue: AdditionalSellerInput = None
        if "RestrictedSetValues" in data:
            self.RestrictedSetValues: RestrictedSetValues = RestrictedSetValues(data["RestrictedSetValues"])
        else:
            self.RestrictedSetValues: RestrictedSetValues = None


class AdditionalSellerInput:
    """
    Additional information required to purchase shipping.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "DataType" in data:
            self.DataType: str = str(data["DataType"])
        else:
            self.DataType: str = None
        if "ValueAsString" in data:
            self.ValueAsString: str = str(data["ValueAsString"])
        else:
            self.ValueAsString: str = None
        if "ValueAsBoolean" in data:
            self.ValueAsBoolean: bool = convert_bool(data["ValueAsBoolean"])
        else:
            self.ValueAsBoolean: bool = None
        if "ValueAsInteger" in data:
            self.ValueAsInteger: int = int(data["ValueAsInteger"])
        else:
            self.ValueAsInteger: int = None
        if "ValueAsTimestamp" in data:
            self.ValueAsTimestamp: Timestamp = Timestamp(data["ValueAsTimestamp"])
        else:
            self.ValueAsTimestamp: Timestamp = None
        if "ValueAsAddress" in data:
            self.ValueAsAddress: Address = Address(data["ValueAsAddress"])
        else:
            self.ValueAsAddress: Address = None
        if "ValueAsWeight" in data:
            self.ValueAsWeight: Weight = Weight(data["ValueAsWeight"])
        else:
            self.ValueAsWeight: Weight = None
        if "ValueAsDimension" in data:
            self.ValueAsDimension: Length = Length(data["ValueAsDimension"])
        else:
            self.ValueAsDimension: Length = None
        if "ValueAsCurrency" in data:
            self.ValueAsCurrency: CurrencyAmount = CurrencyAmount(data["ValueAsCurrency"])
        else:
            self.ValueAsCurrency: CurrencyAmount = None


class AdditionalSellerInputs:
    """
    An additional set of seller inputs required to purchase shipping.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "AdditionalInputFieldName" in data:
            self.AdditionalInputFieldName: str = str(data["AdditionalInputFieldName"])
        else:
            self.AdditionalInputFieldName: str = None
        if "AdditionalSellerInput" in data:
            self.AdditionalSellerInput: AdditionalSellerInput = AdditionalSellerInput(data["AdditionalSellerInput"])
        else:
            self.AdditionalSellerInput: AdditionalSellerInput = None


class Address:
    """
    The postal address information.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "Name" in data:
            self.Name: AddressName = AddressName(data["Name"])
        else:
            self.Name: AddressName = None
        if "AddressLine1" in data:
            self.AddressLine1: AddressLine1 = AddressLine1(data["AddressLine1"])
        else:
            self.AddressLine1: AddressLine1 = None
        if "AddressLine2" in data:
            self.AddressLine2: AddressLine2 = AddressLine2(data["AddressLine2"])
        else:
            self.AddressLine2: AddressLine2 = None
        if "AddressLine3" in data:
            self.AddressLine3: AddressLine3 = AddressLine3(data["AddressLine3"])
        else:
            self.AddressLine3: AddressLine3 = None
        if "DistrictOrCounty" in data:
            self.DistrictOrCounty: DistrictOrCounty = DistrictOrCounty(data["DistrictOrCounty"])
        else:
            self.DistrictOrCounty: DistrictOrCounty = None
        if "Email" in data:
            self.Email: EmailAddress = EmailAddress(data["Email"])
        else:
            self.Email: EmailAddress = None
        if "City" in data:
            self.City: City = City(data["City"])
        else:
            self.City: City = None
        if "StateOrProvinceCode" in data:
            self.StateOrProvinceCode: StateOrProvinceCode = StateOrProvinceCode(data["StateOrProvinceCode"])
        else:
            self.StateOrProvinceCode: StateOrProvinceCode = None
        if "PostalCode" in data:
            self.PostalCode: PostalCode = PostalCode(data["PostalCode"])
        else:
            self.PostalCode: PostalCode = None
        if "CountryCode" in data:
            self.CountryCode: CountryCode = CountryCode(data["CountryCode"])
        else:
            self.CountryCode: CountryCode = None
        if "Phone" in data:
            self.Phone: PhoneNumber = PhoneNumber(data["Phone"])
        else:
            self.Phone: PhoneNumber = None


class CancelShipmentResponse:
    """
    Response schema.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "payload" in data:
            self.payload: Shipment = Shipment(data["payload"])
        else:
            self.payload: Shipment = None
        if "errors" in data:
            self.errors: ErrorList = ErrorList(data["errors"])
        else:
            self.errors: ErrorList = None


class CreateShipmentRequest:
    """
    Request schema.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "ShipmentRequestDetails" in data:
            self.ShipmentRequestDetails: ShipmentRequestDetails = ShipmentRequestDetails(data["ShipmentRequestDetails"])
        else:
            self.ShipmentRequestDetails: ShipmentRequestDetails = None
        if "ShippingServiceId" in data:
            self.ShippingServiceId: ShippingServiceIdentifier = ShippingServiceIdentifier(data["ShippingServiceId"])
        else:
            self.ShippingServiceId: ShippingServiceIdentifier = None
        if "ShippingServiceOfferId" in data:
            self.ShippingServiceOfferId: str = str(data["ShippingServiceOfferId"])
        else:
            self.ShippingServiceOfferId: str = None
        if "HazmatType" in data:
            self.HazmatType: HazmatType = HazmatType(data["HazmatType"])
        else:
            self.HazmatType: HazmatType = None
        if "LabelFormatOption" in data:
            self.LabelFormatOption: LabelFormatOptionRequest = LabelFormatOptionRequest(data["LabelFormatOption"])
        else:
            self.LabelFormatOption: LabelFormatOptionRequest = None
        if "ShipmentLevelSellerInputsList" in data:
            self.ShipmentLevelSellerInputsList: AdditionalSellerInputsList = AdditionalSellerInputsList(
                data["ShipmentLevelSellerInputsList"]
            )
        else:
            self.ShipmentLevelSellerInputsList: AdditionalSellerInputsList = None


class CreateShipmentResponse:
    """
    Response schema.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "payload" in data:
            self.payload: Shipment = Shipment(data["payload"])
        else:
            self.payload: Shipment = None
        if "errors" in data:
            self.errors: ErrorList = ErrorList(data["errors"])
        else:
            self.errors: ErrorList = None


class ItemLevelFields:
    """ """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "Asin" in data:
            self.Asin: str = str(data["Asin"])
        else:
            self.Asin: str = None
        if "AdditionalInputs" in data:
            self.AdditionalInputs: AdditionalInputsList = AdditionalInputsList(data["AdditionalInputs"])
        else:
            self.AdditionalInputs: AdditionalInputsList = None


class GetAdditionalSellerInputsRequest:
    """
    Request schema.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "ShippingServiceId" in data:
            self.ShippingServiceId: ShippingServiceIdentifier = ShippingServiceIdentifier(data["ShippingServiceId"])
        else:
            self.ShippingServiceId: ShippingServiceIdentifier = None
        if "ShipFromAddress" in data:
            self.ShipFromAddress: Address = Address(data["ShipFromAddress"])
        else:
            self.ShipFromAddress: Address = None
        if "OrderId" in data:
            self.OrderId: AmazonOrderId = AmazonOrderId(data["OrderId"])
        else:
            self.OrderId: AmazonOrderId = None


class GetAdditionalSellerInputsResult:
    """
    The payload for the getAdditionalSellerInputs operation.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "ShipmentLevelFields" in data:
            self.ShipmentLevelFields: AdditionalInputsList = AdditionalInputsList(data["ShipmentLevelFields"])
        else:
            self.ShipmentLevelFields: AdditionalInputsList = None
        if "ItemLevelFieldsList" in data:
            self.ItemLevelFieldsList: ItemLevelFieldsList = ItemLevelFieldsList(data["ItemLevelFieldsList"])
        else:
            self.ItemLevelFieldsList: ItemLevelFieldsList = None


class GetAdditionalSellerInputsResponse:
    """
    Response schema.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "payload" in data:
            self.payload: GetAdditionalSellerInputsResult = GetAdditionalSellerInputsResult(data["payload"])
        else:
            self.payload: GetAdditionalSellerInputsResult = None
        if "errors" in data:
            self.errors: ErrorList = ErrorList(data["errors"])
        else:
            self.errors: ErrorList = None


class CurrencyAmount:
    """
    Currency type and amount.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "CurrencyCode" in data:
            self.CurrencyCode: str = str(data["CurrencyCode"])
        else:
            self.CurrencyCode: str = None
        if "Amount" in data:
            self.Amount: float = float(data["Amount"])
        else:
            self.Amount: float = None


class FileContents:
    """
    The document data and checksum.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "Contents" in data:
            self.Contents: str = str(data["Contents"])
        else:
            self.Contents: str = None
        if "FileType" in data:
            self.FileType: FileType = FileType(data["FileType"])
        else:
            self.FileType: FileType = None
        if "Checksum" in data:
            self.Checksum: str = str(data["Checksum"])
        else:
            self.Checksum: str = None


class GetEligibleShipmentServicesRequest:
    """
    Request schema.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "ShipmentRequestDetails" in data:
            self.ShipmentRequestDetails: ShipmentRequestDetails = ShipmentRequestDetails(data["ShipmentRequestDetails"])
        else:
            self.ShipmentRequestDetails: ShipmentRequestDetails = None
        if "ShippingOfferingFilter" in data:
            self.ShippingOfferingFilter: ShippingOfferingFilter = ShippingOfferingFilter(data["ShippingOfferingFilter"])
        else:
            self.ShippingOfferingFilter: ShippingOfferingFilter = None


class GetEligibleShipmentServicesResponse:
    """
    Response schema.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "payload" in data:
            self.payload: GetEligibleShipmentServicesResult = GetEligibleShipmentServicesResult(data["payload"])
        else:
            self.payload: GetEligibleShipmentServicesResult = None
        if "errors" in data:
            self.errors: ErrorList = ErrorList(data["errors"])
        else:
            self.errors: ErrorList = None


class GetEligibleShipmentServicesResult:
    """
    The payload for the getEligibleShipmentServices operation.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "ShippingServiceList" in data:
            self.ShippingServiceList: ShippingServiceList = ShippingServiceList(data["ShippingServiceList"])
        else:
            self.ShippingServiceList: ShippingServiceList = None
        if "RejectedShippingServiceList" in data:
            self.RejectedShippingServiceList: RejectedShippingServiceList = RejectedShippingServiceList(
                data["RejectedShippingServiceList"]
            )
        else:
            self.RejectedShippingServiceList: RejectedShippingServiceList = None
        if "TemporarilyUnavailableCarrierList" in data:
            self.TemporarilyUnavailableCarrierList: TemporarilyUnavailableCarrierList = (
                TemporarilyUnavailableCarrierList(data["TemporarilyUnavailableCarrierList"])
            )
        else:
            self.TemporarilyUnavailableCarrierList: TemporarilyUnavailableCarrierList = None
        if "TermsAndConditionsNotAcceptedCarrierList" in data:
            self.TermsAndConditionsNotAcceptedCarrierList: TermsAndConditionsNotAcceptedCarrierList = (
                TermsAndConditionsNotAcceptedCarrierList(data["TermsAndConditionsNotAcceptedCarrierList"])
            )
        else:
            self.TermsAndConditionsNotAcceptedCarrierList: TermsAndConditionsNotAcceptedCarrierList = None


class GetShipmentResponse:
    """
    Response schema.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "payload" in data:
            self.payload: Shipment = Shipment(data["payload"])
        else:
            self.payload: Shipment = None
        if "errors" in data:
            self.errors: ErrorList = ErrorList(data["errors"])
        else:
            self.errors: ErrorList = None


class Item:
    """
    An Amazon order item identifier and a quantity.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "OrderItemId" in data:
            self.OrderItemId: OrderItemId = OrderItemId(data["OrderItemId"])
        else:
            self.OrderItemId: OrderItemId = None
        if "Quantity" in data:
            self.Quantity: ItemQuantity = ItemQuantity(data["Quantity"])
        else:
            self.Quantity: ItemQuantity = None
        if "ItemWeight" in data:
            self.ItemWeight: Weight = Weight(data["ItemWeight"])
        else:
            self.ItemWeight: Weight = None
        if "ItemDescription" in data:
            self.ItemDescription: ItemDescription = ItemDescription(data["ItemDescription"])
        else:
            self.ItemDescription: ItemDescription = None
        if "TransparencyCodeList" in data:
            self.TransparencyCodeList: TransparencyCodeList = TransparencyCodeList(data["TransparencyCodeList"])
        else:
            self.TransparencyCodeList: TransparencyCodeList = None
        if "ItemLevelSellerInputsList" in data:
            self.ItemLevelSellerInputsList: AdditionalSellerInputsList = AdditionalSellerInputsList(
                data["ItemLevelSellerInputsList"]
            )
        else:
            self.ItemLevelSellerInputsList: AdditionalSellerInputsList = None


class Label:
    """
    Data for creating a shipping label and dimensions for printing the label.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "CustomTextForLabel" in data:
            self.CustomTextForLabel: CustomTextForLabel = CustomTextForLabel(data["CustomTextForLabel"])
        else:
            self.CustomTextForLabel: CustomTextForLabel = None
        if "Dimensions" in data:
            self.Dimensions: LabelDimensions = LabelDimensions(data["Dimensions"])
        else:
            self.Dimensions: LabelDimensions = None
        if "FileContents" in data:
            self.FileContents: FileContents = FileContents(data["FileContents"])
        else:
            self.FileContents: FileContents = None
        if "LabelFormat" in data:
            self.LabelFormat: LabelFormat = LabelFormat(data["LabelFormat"])
        else:
            self.LabelFormat: LabelFormat = None
        if "StandardIdForLabel" in data:
            self.StandardIdForLabel: StandardIdForLabel = StandardIdForLabel(data["StandardIdForLabel"])
        else:
            self.StandardIdForLabel: StandardIdForLabel = None


class LabelCustomization:
    """
    Custom text for shipping labels.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "CustomTextForLabel" in data:
            self.CustomTextForLabel: CustomTextForLabel = CustomTextForLabel(data["CustomTextForLabel"])
        else:
            self.CustomTextForLabel: CustomTextForLabel = None
        if "StandardIdForLabel" in data:
            self.StandardIdForLabel: StandardIdForLabel = StandardIdForLabel(data["StandardIdForLabel"])
        else:
            self.StandardIdForLabel: StandardIdForLabel = None


class LabelDimensions:
    """
    Dimensions for printing a shipping label.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "Length" in data:
            self.Length: LabelDimension = LabelDimension(data["Length"])
        else:
            self.Length: LabelDimension = None
        if "Width" in data:
            self.Width: LabelDimension = LabelDimension(data["Width"])
        else:
            self.Width: LabelDimension = None
        if "Unit" in data:
            self.Unit: UnitOfLength = UnitOfLength(data["Unit"])
        else:
            self.Unit: UnitOfLength = None


class Length:
    """
    The length.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "value" in data:
            self.value: float = float(data["value"])
        else:
            self.value: float = None
        if "unit" in data:
            self.unit: UnitOfLength = UnitOfLength(data["unit"])
        else:
            self.unit: UnitOfLength = None


class PackageDimensions:
    """
    The dimensions of a package contained in a shipment.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "Length" in data:
            self.Length: PackageDimension = PackageDimension(data["Length"])
        else:
            self.Length: PackageDimension = None
        if "Width" in data:
            self.Width: PackageDimension = PackageDimension(data["Width"])
        else:
            self.Width: PackageDimension = None
        if "Height" in data:
            self.Height: PackageDimension = PackageDimension(data["Height"])
        else:
            self.Height: PackageDimension = None
        if "Unit" in data:
            self.Unit: UnitOfLength = UnitOfLength(data["Unit"])
        else:
            self.Unit: UnitOfLength = None
        if "PredefinedPackageDimensions" in data:
            self.PredefinedPackageDimensions: PredefinedPackageDimensions = PredefinedPackageDimensions(
                data["PredefinedPackageDimensions"]
            )
        else:
            self.PredefinedPackageDimensions: PredefinedPackageDimensions = None


class Shipment:
    """
    The details of a shipment, including the shipment status.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "ShipmentId" in data:
            self.ShipmentId: ShipmentId = ShipmentId(data["ShipmentId"])
        else:
            self.ShipmentId: ShipmentId = None
        if "AmazonOrderId" in data:
            self.AmazonOrderId: AmazonOrderId = AmazonOrderId(data["AmazonOrderId"])
        else:
            self.AmazonOrderId: AmazonOrderId = None
        if "SellerOrderId" in data:
            self.SellerOrderId: SellerOrderId = SellerOrderId(data["SellerOrderId"])
        else:
            self.SellerOrderId: SellerOrderId = None
        if "ItemList" in data:
            self.ItemList: ItemList = ItemList(data["ItemList"])
        else:
            self.ItemList: ItemList = None
        if "ShipFromAddress" in data:
            self.ShipFromAddress: Address = Address(data["ShipFromAddress"])
        else:
            self.ShipFromAddress: Address = None
        if "ShipToAddress" in data:
            self.ShipToAddress: Address = Address(data["ShipToAddress"])
        else:
            self.ShipToAddress: Address = None
        if "PackageDimensions" in data:
            self.PackageDimensions: PackageDimensions = PackageDimensions(data["PackageDimensions"])
        else:
            self.PackageDimensions: PackageDimensions = None
        if "Weight" in data:
            self.Weight: Weight = Weight(data["Weight"])
        else:
            self.Weight: Weight = None
        if "Insurance" in data:
            self.Insurance: CurrencyAmount = CurrencyAmount(data["Insurance"])
        else:
            self.Insurance: CurrencyAmount = None
        if "ShippingService" in data:
            self.ShippingService: ShippingService = ShippingService(data["ShippingService"])
        else:
            self.ShippingService: ShippingService = None
        if "Label" in data:
            self.Label: Label = Label(data["Label"])
        else:
            self.Label: Label = None
        if "Status" in data:
            self.Status: ShipmentStatus = ShipmentStatus(data["Status"])
        else:
            self.Status: ShipmentStatus = None
        if "TrackingId" in data:
            self.TrackingId: TrackingId = TrackingId(data["TrackingId"])
        else:
            self.TrackingId: TrackingId = None
        if "CreatedDate" in data:
            self.CreatedDate: Timestamp = Timestamp(data["CreatedDate"])
        else:
            self.CreatedDate: Timestamp = None
        if "LastUpdatedDate" in data:
            self.LastUpdatedDate: Timestamp = Timestamp(data["LastUpdatedDate"])
        else:
            self.LastUpdatedDate: Timestamp = None


class ShipmentRequestDetails:
    """
    Shipment information required for requesting shipping service offers or for creating a shipment.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "AmazonOrderId" in data:
            self.AmazonOrderId: AmazonOrderId = AmazonOrderId(data["AmazonOrderId"])
        else:
            self.AmazonOrderId: AmazonOrderId = None
        if "SellerOrderId" in data:
            self.SellerOrderId: SellerOrderId = SellerOrderId(data["SellerOrderId"])
        else:
            self.SellerOrderId: SellerOrderId = None
        if "ItemList" in data:
            self.ItemList: ItemList = ItemList(data["ItemList"])
        else:
            self.ItemList: ItemList = None
        if "ShipFromAddress" in data:
            self.ShipFromAddress: Address = Address(data["ShipFromAddress"])
        else:
            self.ShipFromAddress: Address = None
        if "PackageDimensions" in data:
            self.PackageDimensions: PackageDimensions = PackageDimensions(data["PackageDimensions"])
        else:
            self.PackageDimensions: PackageDimensions = None
        if "Weight" in data:
            self.Weight: Weight = Weight(data["Weight"])
        else:
            self.Weight: Weight = None
        if "MustArriveByDate" in data:
            self.MustArriveByDate: Timestamp = Timestamp(data["MustArriveByDate"])
        else:
            self.MustArriveByDate: Timestamp = None
        if "ShipDate" in data:
            self.ShipDate: Timestamp = Timestamp(data["ShipDate"])
        else:
            self.ShipDate: Timestamp = None
        if "ShippingServiceOptions" in data:
            self.ShippingServiceOptions: ShippingServiceOptions = ShippingServiceOptions(data["ShippingServiceOptions"])
        else:
            self.ShippingServiceOptions: ShippingServiceOptions = None
        if "LabelCustomization" in data:
            self.LabelCustomization: LabelCustomization = LabelCustomization(data["LabelCustomization"])
        else:
            self.LabelCustomization: LabelCustomization = None


class ShippingOfferingFilter:
    """
    Filter for use when requesting eligible shipping services.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "IncludePackingSlipWithLabel" in data:
            self.IncludePackingSlipWithLabel: bool = convert_bool(data["IncludePackingSlipWithLabel"])
        else:
            self.IncludePackingSlipWithLabel: bool = None
        if "IncludeComplexShippingOptions" in data:
            self.IncludeComplexShippingOptions: bool = convert_bool(data["IncludeComplexShippingOptions"])
        else:
            self.IncludeComplexShippingOptions: bool = None
        if "CarrierWillPickUp" in data:
            self.CarrierWillPickUp: CarrierWillPickUpOption = CarrierWillPickUpOption(data["CarrierWillPickUp"])
        else:
            self.CarrierWillPickUp: CarrierWillPickUpOption = None
        if "DeliveryExperience" in data:
            self.DeliveryExperience: DeliveryExperienceOption = DeliveryExperienceOption(data["DeliveryExperience"])
        else:
            self.DeliveryExperience: DeliveryExperienceOption = None


class ShippingService:
    """
    A shipping service offer made by a carrier.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "ShippingServiceName" in data:
            self.ShippingServiceName: str = str(data["ShippingServiceName"])
        else:
            self.ShippingServiceName: str = None
        if "CarrierName" in data:
            self.CarrierName: str = str(data["CarrierName"])
        else:
            self.CarrierName: str = None
        if "ShippingServiceId" in data:
            self.ShippingServiceId: ShippingServiceIdentifier = ShippingServiceIdentifier(data["ShippingServiceId"])
        else:
            self.ShippingServiceId: ShippingServiceIdentifier = None
        if "ShippingServiceOfferId" in data:
            self.ShippingServiceOfferId: str = str(data["ShippingServiceOfferId"])
        else:
            self.ShippingServiceOfferId: str = None
        if "ShipDate" in data:
            self.ShipDate: Timestamp = Timestamp(data["ShipDate"])
        else:
            self.ShipDate: Timestamp = None
        if "EarliestEstimatedDeliveryDate" in data:
            self.EarliestEstimatedDeliveryDate: Timestamp = Timestamp(data["EarliestEstimatedDeliveryDate"])
        else:
            self.EarliestEstimatedDeliveryDate: Timestamp = None
        if "LatestEstimatedDeliveryDate" in data:
            self.LatestEstimatedDeliveryDate: Timestamp = Timestamp(data["LatestEstimatedDeliveryDate"])
        else:
            self.LatestEstimatedDeliveryDate: Timestamp = None
        if "Rate" in data:
            self.Rate: CurrencyAmount = CurrencyAmount(data["Rate"])
        else:
            self.Rate: CurrencyAmount = None
        if "ShippingServiceOptions" in data:
            self.ShippingServiceOptions: ShippingServiceOptions = ShippingServiceOptions(data["ShippingServiceOptions"])
        else:
            self.ShippingServiceOptions: ShippingServiceOptions = None
        if "AvailableShippingServiceOptions" in data:
            self.AvailableShippingServiceOptions: AvailableShippingServiceOptions = AvailableShippingServiceOptions(
                data["AvailableShippingServiceOptions"]
            )
        else:
            self.AvailableShippingServiceOptions: AvailableShippingServiceOptions = None
        if "AvailableLabelFormats" in data:
            self.AvailableLabelFormats: LabelFormatList = LabelFormatList(data["AvailableLabelFormats"])
        else:
            self.AvailableLabelFormats: LabelFormatList = None
        if "AvailableFormatOptionsForLabel" in data:
            self.AvailableFormatOptionsForLabel: AvailableFormatOptionsForLabelList = (
                AvailableFormatOptionsForLabelList(data["AvailableFormatOptionsForLabel"])
            )
        else:
            self.AvailableFormatOptionsForLabel: AvailableFormatOptionsForLabelList = None
        if "RequiresAdditionalSellerInputs" in data:
            self.RequiresAdditionalSellerInputs: bool = convert_bool(data["RequiresAdditionalSellerInputs"])
        else:
            self.RequiresAdditionalSellerInputs: bool = None


class ShippingServiceOptions:
    """
    Extra services provided by a carrier.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "DeliveryExperience" in data:
            self.DeliveryExperience: DeliveryExperienceType = DeliveryExperienceType(data["DeliveryExperience"])
        else:
            self.DeliveryExperience: DeliveryExperienceType = None
        if "DeclaredValue" in data:
            self.DeclaredValue: CurrencyAmount = CurrencyAmount(data["DeclaredValue"])
        else:
            self.DeclaredValue: CurrencyAmount = None
        if "CarrierWillPickUp" in data:
            self.CarrierWillPickUp: bool = convert_bool(data["CarrierWillPickUp"])
        else:
            self.CarrierWillPickUp: bool = None
        if "CarrierWillPickUpOption" in data:
            self.CarrierWillPickUpOption: CarrierWillPickUpOption = CarrierWillPickUpOption(
                data["CarrierWillPickUpOption"]
            )
        else:
            self.CarrierWillPickUpOption: CarrierWillPickUpOption = None
        if "LabelFormat" in data:
            self.LabelFormat: LabelFormat = LabelFormat(data["LabelFormat"])
        else:
            self.LabelFormat: LabelFormat = None


class RejectedShippingService:
    """
    Information about a rejected shipping service
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "CarrierName" in data:
            self.CarrierName: str = str(data["CarrierName"])
        else:
            self.CarrierName: str = None
        if "ShippingServiceName" in data:
            self.ShippingServiceName: str = str(data["ShippingServiceName"])
        else:
            self.ShippingServiceName: str = None
        if "ShippingServiceId" in data:
            self.ShippingServiceId: ShippingServiceIdentifier = ShippingServiceIdentifier(data["ShippingServiceId"])
        else:
            self.ShippingServiceId: ShippingServiceIdentifier = None
        if "RejectionReasonCode" in data:
            self.RejectionReasonCode: str = str(data["RejectionReasonCode"])
        else:
            self.RejectionReasonCode: str = None
        if "RejectionReasonMessage" in data:
            self.RejectionReasonMessage: str = str(data["RejectionReasonMessage"])
        else:
            self.RejectionReasonMessage: str = None


class TemporarilyUnavailableCarrier:
    """
    A carrier who is temporarily unavailable, most likely due to a service outage experienced by the carrier.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "CarrierName" in data:
            self.CarrierName: str = str(data["CarrierName"])
        else:
            self.CarrierName: str = None


class TermsAndConditionsNotAcceptedCarrier:
    """
    A carrier whose terms and conditions have not been accepted by the seller.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "CarrierName" in data:
            self.CarrierName: str = str(data["CarrierName"])
        else:
            self.CarrierName: str = None


class Weight:
    """
    The weight.
    """

    def __init__(self, data):
        super().__init__()
        self.data = data
        if "Value" in data:
            self.Value: WeightValue = WeightValue(data["Value"])
        else:
            self.Value: WeightValue = None
        if "Unit" in data:
            self.Unit: UnitOfWeight = UnitOfWeight(data["Unit"])
        else:
            self.Unit: UnitOfWeight = None


class ErrorList(list, _List["Error"]):
    """
    A list of error responses returned when a request is unsuccessful.
    """

    def __init__(self, data):
        super().__init__([Error(datum) for datum in data])
        self.data = data


class AvailableCarrierWillPickUpOptionsList(list, _List["AvailableCarrierWillPickUpOption"]):
    """
    List of available carrier pickup options.
    """

    def __init__(self, data):
        super().__init__([AvailableCarrierWillPickUpOption(datum) for datum in data])
        self.data = data


class AvailableDeliveryExperienceOptionsList(list, _List["AvailableDeliveryExperienceOption"]):
    """
    List of available delivery experience options.
    """

    def __init__(self, data):
        super().__init__([AvailableDeliveryExperienceOption(datum) for datum in data])
        self.data = data


class AvailableFormatOptionsForLabelList(list, _List["LabelFormatOption"]):
    """
    The available label formats.
    """

    def __init__(self, data):
        super().__init__([LabelFormatOption(datum) for datum in data])
        self.data = data


class Constraints(list, _List["Constraint"]):
    """
    List of constraints.
    """

    def __init__(self, data):
        super().__init__([Constraint(datum) for datum in data])
        self.data = data


class AdditionalInputsList(list, _List["AdditionalInputs"]):
    """
    A list of additional inputs.
    """

    def __init__(self, data):
        super().__init__([AdditionalInputs(datum) for datum in data])
        self.data = data


class AdditionalSellerInputsList(list, _List["AdditionalSellerInputs"]):
    """
    A list of additional seller input pairs required to purchase shipping.
    """

    def __init__(self, data):
        super().__init__([AdditionalSellerInputs(datum) for datum in data])
        self.data = data


class ItemLevelFieldsList(list, _List["ItemLevelFields"]):
    """
    A list of item level fields.
    """

    def __init__(self, data):
        super().__init__([ItemLevelFields(datum) for datum in data])
        self.data = data


class ItemList(list, _List["Item"]):
    """
    The list of items to be included in a shipment.
    """

    def __init__(self, data):
        super().__init__([Item(datum) for datum in data])
        self.data = data


class LabelFormatList(list, _List["LabelFormat"]):
    """
    List of label formats.
    """

    def __init__(self, data):
        super().__init__([LabelFormat(datum) for datum in data])
        self.data = data


class RestrictedSetValues(list, _List["str"]):
    """
    The set of fixed values in an additional seller input.
    """

    def __init__(self, data):
        super().__init__([str(datum) for datum in data])
        self.data = data


class ShippingServiceList(list, _List["ShippingService"]):
    """
    A list of shipping services offers.
    """

    def __init__(self, data):
        super().__init__([ShippingService(datum) for datum in data])
        self.data = data


class RejectedShippingServiceList(list, _List["RejectedShippingService"]):
    """
    List of services that were for some reason unavailable for this request
    """

    def __init__(self, data):
        super().__init__([RejectedShippingService(datum) for datum in data])
        self.data = data


class TemporarilyUnavailableCarrierList(list, _List["TemporarilyUnavailableCarrier"]):
    """
    A list of temporarily unavailable carriers.
    """

    def __init__(self, data):
        super().__init__([TemporarilyUnavailableCarrier(datum) for datum in data])
        self.data = data


class TermsAndConditionsNotAcceptedCarrierList(list, _List["TermsAndConditionsNotAcceptedCarrier"]):
    """
    List of carriers whose terms and conditions were not accepted by the seller.
    """

    def __init__(self, data):
        super().__init__([TermsAndConditionsNotAcceptedCarrier(datum) for datum in data])
        self.data = data


class TransparencyCodeList(list, _List["TransparencyCode"]):
    """
    A list of transparency codes.
    """

    def __init__(self, data):
        super().__init__([TransparencyCode(datum) for datum in data])
        self.data = data


class InputTargetType(str):
    """
    Indicates whether the additional seller input is at the item or shipment level.
    """


class AddressLine1(str):
    """
    The street address information.
    """


class AddressLine2(str):
    """
    Additional street address information.
    """


class AddressLine3(str):
    """
    Additional street address information.
    """


class AddressName(str):
    """
    The name of the addressee, or business name.
    """


class AmazonOrderId(str):
    """
    An Amazon-defined order identifier, in 3-7-7 format.
    """


class City(str):
    """
    The city.
    """


class CountryCode(str):
    """
    The country code. A two-character country code, in ISO 3166-1 alpha-2 format.
    """


class CustomTextForLabel(str):
    """
        Custom text to print on the label.
    Note: Custom text is only included on labels that are in ZPL format (ZPL203). FedEx does not support CustomTextForLabel.
    """


class DeliveryExperienceType(str):
    """
    The delivery confirmation level.
    """


class DistrictOrCounty(str):
    """
    The district or county.
    """


class EmailAddress(str):
    """
    The email address.
    """


class FileType(str):
    """
    The file type for a label.
    """


class HazmatType(str):
    """
    Hazardous materials options for a package. Consult the terms and conditions for each carrier for more information on hazardous materials.
    """


class ItemQuantity(int):
    """
    The number of items.
    """


class ItemDescription(str):
    """
    The description of the item.
    """


class LabelDimension(float):
    """
    A label dimension.
    """


class LabelFormat(str):
    """
    The label format.
    """


class OrderItemId(str):
    """
    An Amazon-defined identifier for an individual item in an order.
    """


class PackageDimension(float):
    """ """


class PhoneNumber(str):
    """
    The phone number.
    """


class PostalCode(str):
    """
    The zip code or postal code.
    """


class PredefinedPackageDimensions(str):
    """
        An enumeration of predefined parcel tokens. If you specify a PredefinedPackageDimensions token, you are not obligated to use a branded package from a carrier. For example, if you specify the FedEx_Box_10kg token, you do not have to use that particular package from FedEx. You are only obligated to use a box that matches the dimensions specified by the token.
    Note: Please note that carriers can have restrictions on the type of package allowed for certain ship methods. Check the carrier website for all details. Example: Flat rate pricing is available when materials are sent by USPS in a USPS-produced Flat Rate Envelope or Box.
    """


class SellerOrderId(str):
    """
    A seller-defined order identifier.
    """


class ShipmentId(str):
    """
    An Amazon-defined shipment identifier.
    """


class ShipmentStatus(str):
    """
    The shipment status.
    """


class DeliveryExperienceOption(str):
    """
    The delivery confirmation level.
    """


class ShippingServiceIdentifier(str):
    """
    An Amazon-defined shipping service identifier.
    """


class CarrierWillPickUpOption(str):
    """
    Carrier will pick up option.
    """


class StandardIdForLabel(str):
    """
    The type of standard identifier to print on the label.
    """


class StateOrProvinceCode(str):
    """
    The state or province code.
    """


class Timestamp(str):
    """ """


class TrackingId(str):
    """
    The shipment tracking identifier provided by the carrier.
    """


class TransparencyCode(str):
    """
    The Transparency code associated with the item.
    """


class UnitOfLength(str):
    """
    The unit of length.
    """


class UnitOfWeight(str):
    """
    The unit of weight.
    """


class WeightValue(float):
    """
    The weight value.
    """


class AvailableFormatOptionsForLabel:
    """ """

    def __init__(self, data):
        self.data = data
        super().__init__(data)


class MerchantFulfillmentV0Client(__BaseClient):
    """
        Returns a list of shipping service offers that satisfy the specified shipment request details.
    **Usage Plan:**
    | Rate (requests per second) | Burst |
    | ---- | ---- |
    | 1 | 1 |
    For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
    """

    def getEligibleShipmentServicesOld(
        self,
        data: GetEligibleShipmentServicesRequest,
    ):
        url = "/mfn/v0/eligibleServices".format()
        params = {}
        response = self.request(url, method="POST", data=params)
        return {
            200: GetEligibleShipmentServicesResponse,
            400: GetEligibleShipmentServicesResponse,
            401: GetEligibleShipmentServicesResponse,
            403: GetEligibleShipmentServicesResponse,
            404: GetEligibleShipmentServicesResponse,
            429: GetEligibleShipmentServicesResponse,
            500: GetEligibleShipmentServicesResponse,
            503: GetEligibleShipmentServicesResponse,
        }[response.status_code](self._get_response_json(response))

    """
    Returns a list of shipping service offers that satisfy the specified shipment request details.
**Usage Plan:**
| Rate (requests per second) | Burst |
| ---- | ---- |
| 1 | 1 |
For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
    """

    def getEligibleShipmentServices(
        self,
        data: GetEligibleShipmentServicesRequest,
    ):
        url = "/mfn/v0/eligibleShippingServices".format()
        params = {}
        response = self.request(url, method="POST", data=params)
        return {
            200: GetEligibleShipmentServicesResponse,
            400: GetEligibleShipmentServicesResponse,
            401: GetEligibleShipmentServicesResponse,
            403: GetEligibleShipmentServicesResponse,
            404: GetEligibleShipmentServicesResponse,
            429: GetEligibleShipmentServicesResponse,
            500: GetEligibleShipmentServicesResponse,
            503: GetEligibleShipmentServicesResponse,
        }[response.status_code](self._get_response_json(response))

    """
    Returns the shipment information for an existing shipment.
**Usage Plan:**
| Rate (requests per second) | Burst |
| ---- | ---- |
| 1 | 1 |
For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
    """

    def getShipment(
        self,
        shipmentId: str,
    ):
        url = "/mfn/v0/shipments/{shipmentId}".format(
            shipmentId=shipmentId,
        )
        params = {}
        response = self.request(url, method="GET", params=params)
        return {
            200: GetShipmentResponse,
            400: GetShipmentResponse,
            401: GetShipmentResponse,
            403: GetShipmentResponse,
            404: GetShipmentResponse,
            429: GetShipmentResponse,
            500: GetShipmentResponse,
            503: GetShipmentResponse,
        }[response.status_code](self._get_response_json(response))

    """
    Cancel the shipment indicated by the specified shipment identifier.
**Usage Plan:**
| Rate (requests per second) | Burst |
| ---- | ---- |
| 1 | 1 |
For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
    """

    def cancelShipment(
        self,
        shipmentId: str,
    ):
        url = "/mfn/v0/shipments/{shipmentId}".format(
            shipmentId=shipmentId,
        )
        params = {}
        response = self.request(url, method="DELETE", data=params)
        return {
            200: CancelShipmentResponse,
            400: CancelShipmentResponse,
            401: CancelShipmentResponse,
            403: CancelShipmentResponse,
            404: CancelShipmentResponse,
            429: CancelShipmentResponse,
            500: CancelShipmentResponse,
            503: CancelShipmentResponse,
        }[response.status_code](self._get_response_json(response))

    """
    Cancel the shipment indicated by the specified shipment identifer.
**Usage Plan:**
| Rate (requests per second) | Burst |
| ---- | ---- |
| 1 | 1 |
For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
    """

    def cancelShipmentOld(
        self,
        shipmentId: str,
    ):
        url = "/mfn/v0/shipments/{shipmentId}/cancel".format(
            shipmentId=shipmentId,
        )
        params = {}
        response = self.request(url, method="PUT", data=params)
        return {
            200: CancelShipmentResponse,
            400: CancelShipmentResponse,
            401: CancelShipmentResponse,
            403: CancelShipmentResponse,
            404: CancelShipmentResponse,
            429: CancelShipmentResponse,
            500: CancelShipmentResponse,
            503: CancelShipmentResponse,
        }[response.status_code](self._get_response_json(response))

    """
    Create a shipment with the information provided.
**Usage Plan:**
| Rate (requests per second) | Burst |
| ---- | ---- |
| 1 | 1 |
For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
    """

    def createShipment(
        self,
        data: CreateShipmentRequest,
    ):
        url = "/mfn/v0/shipments".format()
        params = {}
        response = self.request(url, method="POST", data=params)
        return {
            200: CreateShipmentResponse,
            400: CreateShipmentResponse,
            401: CreateShipmentResponse,
            403: CreateShipmentResponse,
            404: CreateShipmentResponse,
            429: CreateShipmentResponse,
            500: CreateShipmentResponse,
            503: CreateShipmentResponse,
        }[response.status_code](self._get_response_json(response))

    """
    Get a list of additional seller inputs required for a ship method. This is generally used for international shipping.
**Usage Plan:**
| Rate (requests per second) | Burst |
| ---- | ---- |
| 1 | 1 |
For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
    """

    def getAdditionalSellerInputsOld(
        self,
        data: GetAdditionalSellerInputsRequest,
    ):
        url = "/mfn/v0/sellerInputs".format()
        params = {}
        response = self.request(url, method="POST", data=params)
        return {
            200: GetAdditionalSellerInputsResponse,
            400: GetAdditionalSellerInputsResponse,
            401: GetAdditionalSellerInputsResponse,
            403: GetAdditionalSellerInputsResponse,
            404: GetAdditionalSellerInputsResponse,
            429: GetAdditionalSellerInputsResponse,
            500: GetAdditionalSellerInputsResponse,
            503: GetAdditionalSellerInputsResponse,
        }[response.status_code](self._get_response_json(response))

    """
    Gets a list of additional seller inputs required for a ship method. This is generally used for international shipping.
**Usage Plan:**
| Rate (requests per second) | Burst |
| ---- | ---- |
| 1 | 1 |
For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
    """

    def getAdditionalSellerInputs(
        self,
        data: GetAdditionalSellerInputsRequest,
    ):
        url = "/mfn/v0/additionalSellerInputs".format()
        params = {}
        response = self.request(url, method="POST", data=params)
        return {
            200: GetAdditionalSellerInputsResponse,
            400: GetAdditionalSellerInputsResponse,
            401: GetAdditionalSellerInputsResponse,
            403: GetAdditionalSellerInputsResponse,
            404: GetAdditionalSellerInputsResponse,
            429: GetAdditionalSellerInputsResponse,
            500: GetAdditionalSellerInputsResponse,
            503: GetAdditionalSellerInputsResponse,
        }[response.status_code](self._get_response_json(response))
